<?php
namespace Folha\Logic\ESocial\Eventos\Data;
use Folha\Repositories\GpeEsocialRegistro;

/**
 * Classe provedora do datasource utilizado para a geracao do evento S-1320 - Serviços Prestados mediante cessão de mão
 * de obra.
 *
 * @package Folha\Logic\ESocial\Eventos\Data
 * @author felipesantos
 **/
class S1320
{

    /**
     * Retorna os dados que serao utilizado para a geracao do(s) arquivo(s) do evento S-1320, Serviços Prestados mediante
     * cessão de mão de obra.
     *
     * @param $dsordem                 Define as possíveis formas de filtro utilizadas pela tela de envio de eventos  
     *                                 do e-Social. Pode ser ALFABETICA, MATRICULA, DATA_ADMISSAO e ESTRUTURA. Para este
     *                                 evento, em especial, somente o filtro por ESTRUTURA poderá será relevante.
     * @param $limiteInferior          Limite inferior do filtro aplicado. O significado dos dados trazidos neste campo
     *                                 deverao variar, conforme o parametro dsordem.
     * @param $limiteSuperior          Limite superior do filtro aplicado. O significado dos dados trazidos neste campo
     *                                 deverao variar, conforme o parametro dsordem.
     * @param $inicioPeriodo           Inicio do intervalo que deverá ter os eventos gerados. Somente será utilizado se
     *                                 o parametro "$utilizaIntervaloDeDatas" for igual a "true". 
     * @param $fimPeriodo              Final do intervalo que deverá ter os eventos gerados. Somente será utilizado se
     *                                 o parametro "$utilizaIntervaloDeDatas" for igual a "true".
     * @param $utilizaIntervaloDeDatas Verifica se o dataset deve ser filtrado pelos campos de intervalo da tela de  
     *                                 envio de eventos e-Social, ou se devem enviados os arquivos alterados depois do 
     *                                 ultimo envio.
     * @param $idRetificacao           Identificador de Retificação dos arquivos ou não.
     * @param $nrRecibo                Número do Recibo do primeiro envio em caso de Retificação.
     * @param $idApuracao              Identificador da apuração Mensal ou Anual.
     * @param $nrorg                   Nrorg.
     * @param $versaoHRM               Versao do sistema HRM utilizado para a geracao dos relatorios.
     *
     * @return array
     * @author felipesantos
     **/
    public static function getDataSource($dsordem, $limiteInferior, $limiteSuperior, $inicioPeriodo, $fimPeriodo, 
                                         $utilizaIntervaloDeDatas, $nrorg, $versaoHRM, $idRetificacao, $nrRecibo, $idApuracao)
    {
        $S1320 = GpeEsocialRegistro::dataSetEsocial_S1320(
            $dsordem, $limiteInferior, $limiteSuperior, $inicioPeriodo, $fimPeriodo, 
            $utilizaIntervaloDeDatas, $nrorg, $versaoHRM, $idRetificacao, $nrRecibo, $idApuracao
        );

        // Loop para gerar os estabelecimentos prestadores referentes ao empregador acima
        foreach ($S1320 as &$row) {
            $estabs = GpeEsocialRegistro::s13xx_EstabPrestTomad('S', $row['NRESTRUTURAM'], $inicioPeriodo, $fimPeriodo, $nrorg);

            // Loop para gerar os contratantes referentes ao estabelecimento acima
            $contPrest = 1;
            $prestador = null;
            foreach($estabs as &$prest) {
                $contrats = GpeEsocialRegistro::s13xx_PrestadTomador('S', $prest['CDFILIEMIT'], $inicioPeriodo, $fimPeriodo, null);

                // Loop para gerar as notas referentes ao contratante acima
                $contContr = 1;
                $contratante = null;
                foreach($contrats as &$contrat) {
                    $notas = GpeEsocialRegistro::s13xx_NfServPrestTomad('S', $contrat['CDFILIEMIT'], $prest['CDCLIENTE'], $inicioPeriodo, $fimPeriodo);

                    // Loop para gerar os itens referentes à nota acima
                    $contNF = 1;
                    $nfEmitidas = null;
                    foreach ($notas as &$notafiscal) {
                        $itens = GpeEsocialRegistro::s13xx_ItensNotaFiscal($notafiscal['CDFILIAL'], $notafiscal['NRLANCTONF']);

                        $contItem = 1;
                        $itemNF = null;
                        foreach ($itens as &$item) {
                            $itemNF[$contItem] =
                                array("_EVTFPSERVPRESTADOS_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_NFSEMITIDAS_ITENSNFS" => '1',
                                    "_EVTFPSERVPRESTADOS_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_NFSEMITIDAS_ITENSNFS_NRITEM" => $item['NRITEM'],
                                    "_EVTFPSERVPRESTADOS_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_NFSEMITIDAS_ITENSNFS_TPSERVICO" => $item['TPSERVICO'],
                                    "_EVTFPSERVPRESTADOS_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_NFSEMITIDAS_ITENSNFS_VLRBRUTO" => $item['VLRBRUTO'],
                                    "_EVTFPSERVPRESTADOS_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_NFSEMITIDAS_ITENSNFS_VLRBASERETENCAO" => $item['VLRBASERETENCAO']);
                            $contItem++;
                        }

                        $nfEmitidas[$contNF] =
                            array("_EVTFPSERVPRESTADOS_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_NFSEMITIDAS" => '1',
                                "_EVTFPSERVPRESTADOS_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_NFSEMITIDAS_SERIE" => $notafiscal['SERIE'],
                                "_EVTFPSERVPRESTADOS_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_NFSEMITIDAS_NUMDOCTO" => $notafiscal['NUMDOCTO'],
                                "_EVTFPSERVPRESTADOS_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_NFSEMITIDAS_DTEMISSAONF" => $notafiscal['DTEMISSAONF'],
                                "_EVTFPSERVPRESTADOS_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_NFSEMITIDAS_INDOBRA" => $notafiscal['INDOBRA'],
                                "_EVTFPSERVPRESTADOS_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_NFSEMITIDAS_NRCNO" => $notafiscal['NRCNO'],
                                "_EVTFPSERVPRESTADOS_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_NFSEMITIDAS_VLRBRUTO" => $notafiscal['VLRBRUTO'],
                                "_EVTFPSERVPRESTADOS_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_NFSEMITIDAS_VLRSERVICOS" => $notafiscal['VLRSERVICOS'],
                                "_EVTFPSERVPRESTADOS_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_NFSEMITIDAS_VLRDEDUCOES" => $notafiscal['VLRDEDUCOES'],
                                "_EVTFPSERVPRESTADOS_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_NFSEMITIDAS_VLRBASERETENCAO" => $notafiscal['VLRBASERETENCAO'],
                                "_EVTFPSERVPRESTADOS_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_NFSEMITIDAS_VLRRETENCAOAPURADA" => $notafiscal['VLRRETENCAOAPURADA'],
                                "_EVTFPSERVPRESTADOS_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_NFSEMITIDAS_VLRRETENCAOSUBEMPREITADA" => $notafiscal['VLRRETENCAOSUBEMPREITADA'],
                                "_EVTFPSERVPRESTADOS_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_NFSEMITIDAS_VLRRETENCAO" => $notafiscal['VLRRETENCAO'],
                                "_EVTFPSERVPRESTADOS_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_NFSEMITIDAS_VLRADICIONAL" => $notafiscal['VLRADICIONAL'],
                                "_EVTFPSERVPRESTADOS_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_NFSEMITIDAS_ITENSNFS" => $itemNF);
                        $contNF++;
                    }

                    $contratante[$contContr] =
                        array("_EVTFPSERVPRESTADOS_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE" => '1',
                            "_EVTFPSERVPRESTADOS_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_TPINSCCONTRATANTE" => $contrat['TPINSCCONTRATANTE'],
                            "_EVTFPSERVPRESTADOS_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_NRINSCCONTRATANTE" => $contrat['NRINSCCONTRATANTE'],
                            "_EVTFPSERVPRESTADOS_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_VLRBRUTO" => $contrat['VLRBRUTO'],
                            "_EVTFPSERVPRESTADOS_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_VLRSERVICOS" => $contrat['VLRSERVICOS'],
                            "_EVTFPSERVPRESTADOS_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_VLRBASERETENCAO" => $contrat['VLRBASERETENCAO'],
                            "_EVTFPSERVPRESTADOS_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_VLRRETENCAO" => $contrat['VLRRETENCAO'],
                            "_EVTFPSERVPRESTADOS_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_VLRADICIONAL" => $contrat['VLRADICIONAL'],
                            "_EVTFPSERVPRESTADOS_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_VLRNAORETIDO" => $contrat['VLRNAORETIDO'],
                            "_EVTFPSERVPRESTADOS_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE_NFSEMITIDAS" => $nfEmitidas);
                    $contContr++;
                }

                $prestador[$contPrest] =
                    array("_EVTFPSERVPRESTADOS_INFOSERVPRESTADOS_IDEESTABPRESTADOR" => '1',
                        "_EVTFPSERVPRESTADOS_INFOSERVPRESTADOS_IDEESTABPRESTADOR_TPINSCRICAO" => $prest['ESTABTPINSCRICAO'],
                        "_EVTFPSERVPRESTADOS_INFOSERVPRESTADOS_IDEESTABPRESTADOR_NRINSCRICAO" => $prest['ESTABNRINSCRICAO'],
                        "_EVTFPSERVPRESTADOS_INFOSERVPRESTADOS_IDEESTABPRESTADOR_IDECONTRATANTE" => $contratante);
                $contPrest++;
            }

            $row['_EVTFPSERVPRESTADOS_INFOSERVPRESTADOS_IDEESTABPRESTADOR'][1] = $prestador;
        }

        return $S1320;
    }

}