import {
  Button, Tabs, Form, DialogService, TreeGridEditable, ModalService, Modal,
} from '@zeedhi/common';
import {
  Http, Metadata, Loader, IEventParam,
} from '@zeedhi/core';

export class Pla01300AjusteQuantidades {
  private appController = Loader.getInstance('AppController');
    
  private utilities = Loader.getInstance('Utilities');
  
  public gridEditController = Loader.getInstance('GridEditableController');
  
  public prato = Loader.getInstance('Pla01300PratoController');
  
  public modalAjusteQuantidades!: Modal;
    
  private async createModalAjusteQuantidades() {
    this.modalAjusteQuantidades = await ModalService.createFromJson('planejamento/prato/modals/formAjusteQuantidades', true);
  }

  public closeModalAjusteQuantidades() {
    this.modalAjusteQuantidades.hide();
  }
  
  public openModalAjusteQuantidades(component: any, tabPratos: any) {
    if (tabPratos.activeTab === 2) {
      if (this.prato.operatorValid !== false) {
        this.openModal();
      } else {
        this.utilities.showAlert('Alert', 'pme::modificacaoRecPadrao', 'warning');
        this.prato.openModalGroupOperador(component);
      }
    } else this.openModal();
  }
  
  public openModal() {
    if (!this.modalAjusteQuantidades) {
      this.createModalAjusteQuantidades().then(() => {
        this.modalAjusteQuantidades.show();
      });
    } else {
      this.modalAjusteQuantidades.show();
    }
  }

  public confirmarAjusteQuantidades() {
    const form = Metadata.getInstance<Form>('formFilter');
    if (form.validate()) {
      DialogService.show({
        name: 'finalizar',
        type: 'warning',
        title: 'pme::atencao',
        text: 'pme::desejaProsseguirComAlteracao',
        buttons: [
          {
            name: 'salvarAjusteQuantidades',
            component: 'ZdButton',
            label: 'pme::sim',
            events: { click: () => this.salvarRowsAjusteQuantidades() },
            outline: true,
          },
          {
            name: 'no',
            component: 'ZdButton',
            label: 'pme::nao',
            events: { click: () => DialogService.hide() },
          },
          {
            name: 'progressLine',
            component: 'ZdProgress',
            label: 'Progress',
            indeterminate: true,
            cssClass: 'loading-progress-line',
          },
        ],
      });
    }
  }

  private verificaCampos({ component }: IEventParam<Button>) {
    const tabPratos: Tabs = Metadata.getInstance('tabPratos');
    
    if (tabPratos.activeTab === 2) {
      this.openModalAjusteQuantidades(component, tabPratos);
    } else if (tabPratos.activeTab === 3) {
      const formFiltroTpCard = Metadata.getInstance<Form>('FORM_TIPOCARD');
      if (formFiltroTpCard.validate()) this.openModalAjusteQuantidades(component, tabPratos);
      else {
        this.utilities.showAlert('alert', 'pme::tipoCardapioDeveSerInformado', 'error');
        DialogService.hide();
      }
    } else if (tabPratos.activeTab === 4) {
      const formFiltroUnidade = Metadata.getInstance<Form>('FORM_LOCAL');
      if (formFiltroUnidade.validate()) this.openModalAjusteQuantidades(component, tabPratos);
      else {
        this.utilities.showAlert('alert', 'pme::unidDeveSerInformado', 'error');
        DialogService.hide();
      }
    } else if (tabPratos.activeTab === 5) {
      const formFiltroServico = Metadata.getInstance<Form>('FORM_SERVICE');
      if (formFiltroServico.validate()) this.openModalAjusteQuantidades(component, tabPratos);
      else {
        this.utilities.showAlert('alert', 'pme::unidEservDevemSerInformados', 'error');
        DialogService.hide();
      }
    } else if (tabPratos.activeTab === 6) {
      const formPadQuali = Metadata.getInstance<Form>('FORM_PADRAOQUALIDADE');
      if (formPadQuali.validate()) this.openModalAjusteQuantidades(component, tabPratos);
      else {
        this.utilities.showAlert('alert', 'pme::padraoQualidadeDeveSerInformado', 'error');
        DialogService.hide();
      }
    } else if (tabPratos.activeTab === 7) {
      const formRegiao = Metadata.getInstance<Form>('FORM_REGIAO');
      if (formRegiao.validate()) this.openModalAjusteQuantidades(component, tabPratos);
      else {
        this.utilities.showAlert('alert', 'pme::regiaoDeveSerInformado', 'error');
        DialogService.hide();
      }
    } else {
      this.openModalAjusteQuantidades(component, tabPratos);
    }
  }

  private salvarRowsAjusteQuantidades() {
    const salvar = Metadata.getInstance<Button>('salvarAjusteQuantidades');
    this.utilities.activeLoadingButton(salvar);
    
    const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
    const currentRow = plateTree.datasource.currentRow;
    const prato = currentRow.CDPRATO;
    const filAux = currentRow.CDFILAUXPRAT || 'P';
    
    const form = Metadata.getInstance<Form>('formFilter');
    const formValue = form.value;
    const tabPratos: Tabs = Metadata.getInstance('tabPratos');
  
    let tipoReceita;
    let tipocard;
    let cdfilial;
    let cdserv;
    let padraoQuali;
    let regiao;
    let grid: any;
    const central = this.appController.getCdCentral();
  
    if (tabPratos.activeTab === 2) {
      tipoReceita = 'P';
      grid = Metadata.getInstance('RECIPE_STANDARD');
    } else if (tabPratos.activeTab === 3) {
      grid = Metadata.getInstance('RECIPE_TIPOCARD');
      tipoReceita = 'C';
      const formFiltroTpCard = Metadata.getInstance<Form>('FORM_TIPOCARD');
      tipocard = formFiltroTpCard.value.TIPOCARD?.CDTIPOCARD;
      if (tipocard === undefined) {
        this.utilities.showAlert('alert', 'pme::tipoCardapioDeveSerInformado', 'error');
      }
    } else if (tabPratos.activeTab === 4) {
      grid = Metadata.getInstance('RECIPE_LOCAL');
      const formFiltroUnidade = Metadata.getInstance<Form>('FORM_LOCAL');
      cdfilial = formFiltroUnidade.value.BRANCH_LOCAL?.CDFILIAL;
      tipoReceita = 'L';
      if (cdfilial === undefined) {
        this.utilities.showAlert('alert', 'pme::unidDeveSerInformado', 'error');
      }
    } else if (tabPratos.activeTab === 5) {
      tipoReceita = 'S';
      grid = Metadata.getInstance('RECIPE_SERVICE');
      const formFiltroServico = Metadata.getInstance<Form>('FORM_SERVICE');
      cdfilial = formFiltroServico.value.BRANCH_SERVICE?.CDFILIAL;
      cdserv = formFiltroServico.value.SERVICE?.CDSERVFILI;
      if (cdserv === undefined) {
        this.utilities.showAlert('alert', 'pme::unidEservDevemSerInformados', 'error');
      }
    } else if (tabPratos.activeTab === 7) {
      const formRegiao = Metadata.getInstance<Form>('FORM_REGIAO');
      if (formRegiao.validate()) {
        grid = Metadata.getInstance('RECIPE_REGION');
        padraoQuali = formRegiao.value.NMPADRAOQUALIDADE.NRPADRAOQUALIDADE;
        regiao = formRegiao.value.NMREGIAO.CDREGIAO;
        tipoReceita = 'R';
      } else this.utilities.showAlert('alert', 'pme::regiaoDeveSerInformado', 'error');
    } else if (tabPratos.activeTab === 6) {
      const formPadQuali = Metadata.getInstance<Form>('FORM_PADRAOQUALIDADE');
      if (formPadQuali.validate()) {
        grid = Metadata.getInstance('RECIPE_PADRAOQUALIDADE');
        padraoQuali = formPadQuali.value.NMPADRAOQUALIDADE.NRPADRAOQUALIDADE;
        tipoReceita = 'Q';
      } else this.utilities.showAlert('alert', 'pme::padraoQualidadeDeveSerInformado', 'error');
    }
  
    const ajusteQtd = {
      CDPRATO: prato,
      CDFILAUXPRAT: filAux,
      OPERACAO: formValue.OPERACAO,
      QUANTIDADE: formValue.QUANTIDADE,
      TIPORECEITA: tipoReceita,
      CDSERVFILI: cdserv,
      CDTIPOCARD: tipocard,
      CDFILIAL: cdfilial,
      CDFILCENTPME: central,
      NRPADRAOQUALIDADE: padraoQuali,
      CDREGIAO: regiao,
    };
    
    Http.post('/saveAjusteQuantidades', { ajusteQtd }).then(() => {
      this.utilities.showAlert('alert', 'pme::salvoComSucesso', 'success');
    }).catch((error) => {
      this.utilities.showAlert('alertError', error, 'error');
    }).finally(() => {
      this.utilities.disableLoadingButton(salvar);
      this.closeModalAjusteQuantidades();
      DialogService.hide();
      this.gridEditController.reload({ component: grid });
    });
  }
}
