import {
  Loader, Metadata, Config, IEventParam, IDictionary, I18n,
} from '@zeedhi/core';
import {
  Form, Button, Select,
} from '@zeedhi/common';
import { PmeMask } from '@/config';
  
export class Pme03800HistoricoReqAnalitica {
  public reportController = Loader.getInstance('ReportController');

  public appController = Loader.getInstance('AppController');

  public utilities = Loader.getInstance('Utilities');
  
  public defaultReport({ component, element }: IEventParam<Select>) {
    const nlength = element?.baseURI.split('/').length ?? 4;
    const elBaseURI = element?.baseURI.split('/')[nlength - 1];
    const defaultBaseURI = 'pme00800_calculo_previsao_consumo';
    
    const dataPrevCons = [
      {
        REPORT_NAME: I18n.translate('pme::historicoCalcPrevConsAnalOper'),
        CD_REPORT_CODE: 'PME03700',
      },
      {
        REPORT_NAME: I18n.translate('pme::historicoCalcPrevConsSintOper'),
        CD_REPORT_CODE: 'PME03701',
      },
    ];
    
    const dataReqAnali = [
      {
        REPORT_NAME: I18n.translate('pme::historicoRequiAnaliticaPorOper'),
        CD_REPORT_CODE: 'PME03800',
      },
      {
        REPORT_NAME: I18n.translate('pme::historicoRequiSinteticoPorOper'),
        CD_REPORT_CODE: 'PME03801',
      },
    ];
    
    const data = (elBaseURI === defaultBaseURI) ? dataPrevCons : dataReqAnali;

    component.datasource.data = data;
    component.setValue(component.datasource.data[0]);
  }

  public setFilterTpCardapio({ component }: IEventParam<Select>) {
    const conditions = [
      {
        name: 'CDFILCENTPME',
        operator: '=',
        value: this.appController.getCdCentral(),
      },
      {
        name: 'NRPASTATCARD',
        operator: '=',
        value: null,
      },
    ];
    
    component.datasource.filter = conditions;
    component.datasource.get();
  }

  /* public setFilterAgreg({ component }: IEventParam<Select>) {
    const conditions = [
      {
        name: 'CDFILCENTPME',
        operator: '=',
        value: this.appController.getCdCentral(),
      },
      {
        name: 'CDGRUPFILI',
        operator: '=',
        value: 'T',
      },
    ];
    
    component.datasource.filter = conditions;
    component.datasource.get();
  } */

  public generateReport({ component }: IEventParam<Button>) {
    const form = Metadata.getInstance<Form>('formHistorico');
    if (this.utilities.centralIsValid() && form.validate()) {
      const row: IDictionary = form.value;
      this.setParams(row);
      
      // row.reportFormat = 'pdf';
      component.name = 'pdf';
      this.reportController.callGenerateReport(component, row, 'report/HistoricoRequisicao');
    }
  }
  
  private setParams(row: IDictionary) {
    const mask: string = (Config.masks.productMask as PmeMask).pattern;
    row.CDFILCENTPME = this.appController.getCdCentral();
    row.NMFILCENTPME = this.appController.getNmCentral();
    row.REPORT_NAME = row.REPORT.REPORT_NAME;
    row.CD_REPORT_CODE = row.REPORT.CD_REPORT_CODE;
    row.PRODUCTMASK = this.utilities.formatReportMask(mask);
  }

  public clearFields({ component }: IEventParam<Select>) {
    const unidade = Metadata.getInstance<Select>('unidadeHistorico');
    const servico = Metadata.getInstance<Select>('servicoHistorico');

    if (component.name === 'tipoCardHistorico') {
      servico.setValue('');
      unidade.setValue('');
    } else unidade.setValue('');
  }
}
